Parallel data generation: Source and Sink and generate_in_chunks
These traits and function are used to generate data in parallel and write it to a sink in streaming fashion (chunks). This is useful for generating large datasets that don’t fit in memory.
Traits
- Sink
- Something that can write the contents of a buffer somewhere
- Source
- Something that knows how to generate data into a buffer
Functions
- generate_
in_ chunks - Generates data in parallel from a series of
Sourceand writes to aSink