pub trait Sink: Send {
// Required methods
fn sink(&mut self, buffer: &[u8]) -> Result<(), Error>;
fn flush(self) -> Result<(), Error>;
}Expand description
Something that can write the contents of a buffer somewhere
For example, this is implemented for a file writer.