pub trait Source: Send {
// Required methods
fn create(self, buffer: Vec<u8>) -> Vec<u8> ⓘ;
fn header(&self, buffer: Vec<u8>) -> Vec<u8> ⓘ;
}Expand description
Something that knows how to generate data into a buffer
For example, this is implemented for the different generators in the tpchgen crate